@@ -1,4 +1,4 @@
-/* $OpenBSD: openssl.c,v 1.18 2015/10/16 13:37:44 millert Exp $ */
+/* $OpenBSD: openssl.c,v 1.22 2015/12/01 01:24:47 beck Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -440,7 +440,7 @@ main(int argc, char **argv)
 	arg.data = NULL;
 	arg.count = 0;
 
-	if (pledge("stdio inet rpath wpath cpath proc flock tty", NULL) == -1) {
+	if (pledge("stdio inet dns rpath wpath cpath proc flock tty", NULL) == -1) {
 		fprintf(stderr, "openssl: pledge: %s\n", strerror(errno));
 		exit(1);
 	}
